@@ -4,7 +4,7 @@ package Chart::GGPlot;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0002_01'; # TRIAL VERSION
+our $VERSION = '0.0002_02'; # TRIAL VERSION
 
 use Data::Munge qw(elem);
 use Data::Frame::Types qw(DataFrame);
@@ -60,6 +60,11 @@ fun qplot (
     # Can't do :$log in func params as it would conflict with $log
     # from Log::Any.
     my $log_mode = $rest{log} // '';
+    state $supported_log_modes = ['', 'x', 'y', 'xy'];
+    unless ( elem( $log_mode, $supported_log_modes ) ) {
+        die "'log' shall be one of "
+          . join( ', ', map { qq("$_") } @$supported_log_modes );
+    }
 
     my $all_aesthetics = Chart::GGPlot::Aes->all_aesthetics;
 
@@ -129,7 +134,7 @@ Chart::GGPlot - ggplot2 port in Perl
 
 =head1 VERSION
 
-version 0.0002_01
+version 0.0002_02
 
 =head1 STATUS
 
@@ -180,6 +185,13 @@ Example exported image files:
 
 See the C<examples> dir in the library's distribution for more examples.
 
+=head2 Document Conventions
+
+Function signatures in docs of this library follow the
+L<Function::Parameters> conventions, for example,
+
+    myfunc(Type1 $positional_parameter, Type2 :$named_parameter)
+
 =head1 FUNCTIONS
 
 =head2 ggplot
@@ -191,11 +203,59 @@ See L<Chart::GGPlot::Plot> for details.
 
 =head2 qplot
 
-    qplot(Piddle1D :$x, Piddle1D :$y, Str :$geom='auto',
+    qplot((Piddle1D|ArrayRef) :$x, (Piddle1D|ArrayRef) :$y,
+        Str :$geom='auto',
         :$xlim=undef, :$ylim=undef,
-        :$log='', :$title=undef, :$xlab='x', :$ylab='y',
+        Str :$log='',
+        Maybe[Str] :$title=undef, Str :$xlab='x', Str :$ylab='y',
         %rest)
 
+Arguments:
+
+=over 4
+
+=item *
+
+$x, $y
+
+Data. Supports either 1D piddles or arrayrefs. When arrayref is specified, it
+would be converted to either a numeric piddle or a PDL::SV piddle, guessing by
+its contents.
+
+=item *
+
+$geom
+
+Geom type. C<"auto"> is treated as C<'point'>.
+It would internally call a C<geom_${geom}> function.
+
+=item *
+
+$xlim, $ylim
+
+Axes limits.
+
+=item *
+
+$log
+
+Which axis use logarithmic scale?
+One of C<''>, C<'x'>, C<'y'>, C<'xy'>.
+
+=item *
+
+$title
+
+Plot title. Default is C<undef>, for no title.
+
+=item *
+
+$xlabel, $ylabel
+
+Axes labels.
+
+=back
+
 =head1 ENVIRONMENT VARIABLES
 
 =head2 CHART_GGPLOT_TRACE
