@@ -5,7 +5,7 @@ package Chart::GGPlot::Backend::Plotly;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0002_01'; # TRIAL VERSION
+our $VERSION = '0.0002_02'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend);
 
@@ -125,7 +125,7 @@ method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
             sub {
                 my ($d) = @_;
 
-                my $trace = $class_geom_impl->to_trace($d, $params);
+                my $trace = $class_geom_impl->to_trace($d, $params, $plot);
 
                 # If we need a legend, set legend info.
                 my $show_legend =
@@ -228,10 +228,16 @@ method _to_plotly ($plot_built) {
             return ($theme->at("${elname}.${xy}") // $theme->at($elname));
         };
 
-        my $sc =
-            $plot->coordinates->DOES('Chart::GGPlot::Coord::Flip')
-          ? $scales->{ $xy eq 'x' ? 'y' : 'x' }
-          : $scales->{$xy};
+        my $axis_name;
+        my $sc;
+        if ( $plot->coordinates->DOES('Chart::GGPlot::Coord::Flip') ) {
+            my $new_xy = $xy eq 'x' ? 'y' : 'x';
+            $axis_name = "${new_xy}axis";
+            $sc = $scales->{$new_xy};
+        } else {
+            $axis_name = "${xy}axis";
+            $sc = $scales->{$xy};
+        }
 
         my $axis_title = $sc->name // $labels->at($xy) // '';
 
@@ -276,7 +282,7 @@ method _to_plotly ($plot_built) {
         my $el_panel_grid = $theme_el->('panel_grid_major')
           // $theme->at('panel_grid');
 
-        $plotly_layout{"${xy}axis"} = {
+        $plotly_layout{$axis_name} = {
             range     => $range,
             zeroline  => JSON::false,
             autorange => JSON::false,
@@ -455,7 +461,7 @@ Chart::GGPlot::Backend::Plotly - Plotly backend for Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0002_01
+version 0.0002_02
 
 =head1 DESCRIPTION
 
@@ -473,13 +479,21 @@ Returns a L<Chart::Plotly> object.
 
     show($ggplot, HashRef $opts={})
 
-Show the plot like in web browser.
+Show the plot in web browser.
+
+On POSIX systems L<Chart::Plotly> internally uses L<Browser::Open> to open
+the browser. L<Browser::Open> has a default list of browsers and tries
+them one by one. You may want to override that behavior by set env var
+C<BROWSER> to force a browser command on your system, for example, 
+
+    export BROWSER=chromium-browser
 
 =head2 save
 
     save($ggplot, $filename, HashRef $opts={})
 
-Export the plot to a static image file.
+Export the plot to a static image file. This internally uses
+L<Chart::Plotly::Image::Orca>.
 
 Below options are supported for C<$opts>:
 
@@ -499,7 +513,9 @@ height
 
 L<https://plot.ly/|Plotly>
 
-L<Chart::GGPlot::Backend>, L<Chart::Plotly>
+L<Chart::GGPlot::Backend>
+
+L<Chart::Plotly>, L<Chart::Plotly::Image::Orca>
 
 =head1 AUTHOR
 
