@@ -5,14 +5,14 @@ package Chart::GGPlot::Layout;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0002_01'; # TRIAL VERSION
+our $VERSION = '0.0002_02'; # TRIAL VERSION
 
 use Data::Frame::Types qw(DataFrame);
 use Data::Munge qw(elem);
 use List::AllUtils qw(pairwise);
 use PDL::Primitive qw(which);
 use Types::PDL qw(Piddle1D);
-use Types::Standard qw(ArrayRef InstanceOf HashRef Bool);
+use Types::Standard qw(ArrayRef InstanceOf HashRef Maybe);
 
 use Chart::GGPlot::Types qw(:all);
 use Chart::GGPlot::Coord::Functions qw(:all);
@@ -31,7 +31,10 @@ has [qw(coord_params facet_params)] => (
 
 has layout => ( is => 'rw', isa => DataFrame, init_arg => undef );
 
-has [qw(panel_scales_x panel_scales_y)] => ( is => 'rw' );
+has [qw(panel_scales_x panel_scales_y)] => (
+    is  => 'rw',
+    isa => Maybe [ArrayRef]
+);
 has panel_params => ( is => 'rwp', isa => ArrayRef [HashRef] );
 
 method setup (ArrayRef $data, $plot_data=Data::Frame->new()) {
@@ -264,7 +267,7 @@ Chart::GGPlot::Layout - Layout
 
 =head1 VERSION
 
-version 0.0002_01
+version 0.0002_02
 
 =head1 DESCRIPTION
 
