@@ -5,7 +5,7 @@ package Chart::GGPlot::Plot;
 use Chart::GGPlot::Class;
 use namespace::autoclean;
 
-our $VERSION = '0.0002_01'; # TRIAL VERSION
+our $VERSION = '0.0002_02'; # TRIAL VERSION
 
 use Autoload::AUTOCAN;
 use Data::Frame::Types qw(DataFrame);
@@ -68,6 +68,7 @@ method AUTOCAN ($method) {
         [ ( ConsumerOf ['Chart::GGPlot::Facet'] ),  'facet' ],
         [ ( ConsumerOf ['Chart::GGPlot::Layer'] ),  'add_layer' ],
         [ ( ConsumerOf ['Chart::GGPlot::Labels'] ), 'add_labels' ],
+        [ ( ConsumerOf ['Chart::GGPlot::Coord'] ),  'add_coord' ],
         [ ( ConsumerOf ['Chart::GGPlot::Guide'] ),  'add_guide' ],
         [ ( ConsumerOf ['Chart::GGPlot::Scale'] ),  'add_scale' ],
         [ ( ConsumerOf ['Chart::GGPlot::Theme'] ),  '_set__theme' ],
@@ -125,7 +126,7 @@ has scales => (
 );
 has _theme   => ( is => 'rwp', isa => InstanceOf['Chart::GGPlot::Theme'] );
 has coordinates => (
-    is      => 'rw',
+    is      => 'rwp',
     isa     => Coord,
     default => sub {
         Chart::GGPlot::Coord::Functions::coord_cartesian( default => true );
@@ -227,6 +228,12 @@ method add_scale ($scale) {
     return $self;
 }
 
+
+method add_coord($coord) {
+    $self->_set_coordinates($coord);
+    return $self;
+}
+
 classmethod make_labels($mapping) {
     state $strip = sub {    # strip_dots() in R ggplot2
         my ($aesthetic, $expr) = @_; 
@@ -266,7 +273,7 @@ Chart::GGPlot::Plot - ggplot class
 
 =head1 VERSION
 
-version 0.0002_01
+version 0.0002_02
 
 =head1 DESCRIPTION
 
@@ -341,6 +348,12 @@ You normally don't have to explicitly call this method.
 
 You normally don't have to explicitly call this method.
 
+=head2 add_coord
+
+    add_coord($scale)
+
+You normally don't have to explicitly call this method.
+
 =head1 MORE METHODS
 
 This class uses Perl's autoloading feature, to allow this class to get
