@@ -4,7 +4,7 @@ package Chart::GGPlot::Util;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0002_01'; # TRIAL VERSION
+our $VERSION = '0.0002_02'; # TRIAL VERSION
 
 use Data::Dumper::Concise ();
 
@@ -17,6 +17,7 @@ use Math::Trig ();
 use constant PI => Math::Trig::pi;
 
 use List::AllUtils qw(min);
+use Module::Load;
 use PDL::Primitive qw(which);
 use Package::Stash;
 use Types::PDL qw(Piddle1D PiddleFromAny);
@@ -46,6 +47,7 @@ my @export_all = (
       split_indices
       find_line_formula spiral_arc_length
       has_groups
+      collect_functions_from_package
       ),
 );
 
@@ -257,6 +259,7 @@ fun split_indices (Piddle1D $indices, $n=$indices->max) {
     return [ map { pdl($_) } @rslt ];
 }
 
+
 fun resolution(Piddle1D $x, $zero=true) {
     if ($x->type < PDL::float or zero_range(range_($x, true))) {
         return 1;
@@ -284,6 +287,30 @@ fun has_groups ($df) {
     return ( $df->at('group')->at(0) >= 0 );
 }
 
+sub collect_functions_from_package {
+    my ($package) = @_; 
+
+    load $package;
+
+    my ($caller_package) = caller();
+    my @func_names;
+    my $funcs = $package->ggplot_functions();
+    for (@$funcs) {
+        my $name = $_->{name};
+
+        no strict 'refs';
+        if (defined &{$name}) {
+            warn qq{Duplicate function definitions for "$name". } . 
+                "Definition from package $package would mask earlier " .
+                "definition loaded into " . __PACKAGE__ . ".";
+        }
+
+        *{"${caller_package}::${name}"} = $_->{code};
+        push @func_names, $name;
+    }   
+    return @func_names;
+}
+
 1;
 
 __END__
@@ -298,7 +325,7 @@ Chart::GGPlot::Util - Utility functions
 
 =head1 VERSION
 
-version 0.0002_01
+version 0.0002_02
 
 =head1 FUNCTIONS
 
@@ -361,6 +388,20 @@ This can be used in a packge like
 
     our @EXPORT_OK = alias_color_functions(__PACKAGE__, @function_names);
 
+=head2 resolution
+
+    resolution(Piddle1D $x, $zero=true)
+
+The resolution is the smallest non-zero distance between adjacent values.
+
+If C<$x> has a single value, or an interger vector which can be assumed to
+represent a discrete value, then the resolution is 1.
+If C<$x> is a float vector, the resolution is the minimal distance between
+ajacent values in sorted C<$x>.
+
+If C<$zero> is true, 0 would be inserted into the vector, if it's does not
+already in the vector, when computing the resolution.
+
 =head2 stat
 
 Can be used in C<aes()> quosure values as a flag to Chart::GGPlot to
